@@ -44,24 +44,24 @@ class PermissionPermissionBackendTestCase(TestCase):
             'permission.delete_article',
         ]
         registry.get_handlers = MagicMock(return_value=[
-            MagicMock(get_permissions=MagicMock(return_value=perms),
+            MagicMock(get_supported_permissions=MagicMock(return_value=perms),
                       has_perm=MagicMock(return_value=False)),
-            MagicMock(get_permissions=MagicMock(return_value=perms),
+            MagicMock(get_supported_permissions=MagicMock(return_value=perms),
                       has_perm=MagicMock(return_value=True)),
         ])
 
         backend = PermissionBackend()
         self.assertFalse(registry.get_handlers.called)
-        self.assertFalse(registry.get_handlers()[0].get_permissions.called)
-        self.assertFalse(registry.get_handlers()[1].get_permissions.called)
+        self.assertFalse(registry.get_handlers()[0].get_supported_permissions.called)
+        self.assertFalse(registry.get_handlers()[1].get_supported_permissions.called)
         self.assertFalse(registry.get_handlers()[0].has_perm.called)
         self.assertFalse(registry.get_handlers()[1].has_perm.called)
 
         self.assertTrue(backend.has_perm(self.user, self.perm1))
 
         self.assertTrue(registry.get_handlers.called)
-        self.assertTrue(registry.get_handlers()[0].get_permissions.called)
-        self.assertTrue(registry.get_handlers()[1].get_permissions.called)
+        self.assertTrue(registry.get_handlers()[0].get_supported_permissions.called)
+        self.assertTrue(registry.get_handlers()[1].get_supported_permissions.called)
         self.assertTrue(registry.get_handlers()[0].has_perm.called)
         self.assertTrue(registry.get_handlers()[1].has_perm.called)
 
@@ -72,24 +72,24 @@ class PermissionPermissionBackendTestCase(TestCase):
             'permission.delete_article',
         ]
         registry.get_handlers = MagicMock(return_value=[
-            MagicMock(get_permissions=MagicMock(return_value=perms),
+            MagicMock(get_supported_permissions=MagicMock(return_value=perms),
                       has_perm=MagicMock(return_value=False)),
-            MagicMock(get_permissions=MagicMock(return_value=perms),
+            MagicMock(get_supported_permissions=MagicMock(return_value=perms),
                       has_perm=MagicMock(return_value=True)),
         ])
 
         backend = PermissionBackend()
         self.assertFalse(registry.get_handlers.called)
-        self.assertFalse(registry.get_handlers()[0].get_permissions.called)
-        self.assertFalse(registry.get_handlers()[1].get_permissions.called)
+        self.assertFalse(registry.get_handlers()[0].get_supported_permissions.called)
+        self.assertFalse(registry.get_handlers()[1].get_supported_permissions.called)
         self.assertFalse(registry.get_handlers()[0].has_perm.called)
         self.assertFalse(registry.get_handlers()[1].has_perm.called)
 
         self.assertTrue(backend.has_perm(self.user, self.perm1, self.article))
 
         self.assertTrue(registry.get_handlers.called)
-        self.assertTrue(registry.get_handlers()[0].get_permissions.called)
-        self.assertTrue(registry.get_handlers()[1].get_permissions.called)
+        self.assertTrue(registry.get_handlers()[0].get_supported_permissions.called)
+        self.assertTrue(registry.get_handlers()[1].get_supported_permissions.called)
         self.assertTrue(registry.get_handlers()[0].has_perm.called)
         self.assertTrue(registry.get_handlers()[1].has_perm.called)
 
@@ -154,3 +154,32 @@ class PermissionPermissionBackendTestCase(TestCase):
         self.assertRaises(ObjectDoesNotExist,
                 self.user.has_perm,
                 'permissions.nil_permission')
+
+    def test_has_module_perms(self):
+        perms = [
+            'permission.add_article',
+            'permission.change_article',
+            'permission.delete_article',
+        ]
+        app_labels = ['permission']
+        registry.get_handlers = MagicMock(return_value=[
+            MagicMock(get_supported_app_labels=MagicMock(return_value=app_labels),
+                      has_module_perms=MagicMock(return_value=False)),
+            MagicMock(get_supported_app_labels=MagicMock(return_value=app_labels),
+                      has_module_perms=MagicMock(return_value=True)),
+        ])
+
+        backend = PermissionBackend()
+        self.assertFalse(registry.get_handlers.called)
+        self.assertFalse(registry.get_handlers()[0].get_supported_app_labels.called)
+        self.assertFalse(registry.get_handlers()[1].get_supported_app_labels.called)
+        self.assertFalse(registry.get_handlers()[0].has_module_perms.called)
+        self.assertFalse(registry.get_handlers()[1].has_module_perms.called)
+
+        self.assertTrue(backend.has_module_perms(self.user, 'permission'))
+
+        self.assertTrue(registry.get_handlers.called)
+        self.assertTrue(registry.get_handlers()[0].get_supported_app_labels.called)
+        self.assertTrue(registry.get_handlers()[1].get_supported_app_labels.called)
+        self.assertTrue(registry.get_handlers()[0].has_module_perms.called)
+        self.assertTrue(registry.get_handlers()[1].has_module_perms.called)
